@@ -9,7 +9,8 @@ import schedlib as s
 # import matplotlib and call .use immediately
 import matplotlib
 matplotlib.use("Qt5Agg")
-matplotlib.rcParams["toolbar"] = "toolmanager"
+with shut_up_mpl():
+    matplotlib.rcParams["toolbar"] = "toolmanager"
 
 # in matplotlib version 3.3 the internal epoch was changed from year 1 to 1970
 # this epoch is used to convert dates to floating points internally
@@ -46,7 +47,8 @@ from astropy.time import Time
 from PyQt5.QtWidgets import QApplication, QWidget, QFrame, QScrollArea, \
     QTabWidget, QPushButton, QCheckBox, QGroupBox, QLabel, QLineEdit, \
     QComboBox, QMenu, QRadioButton, \
-    QVBoxLayout, QHBoxLayout, QGridLayout, QButtonGroup
+    QVBoxLayout, QHBoxLayout, QGridLayout, QButtonGroup, \
+    QMessageBox
 from PyQt5.QtCore import pyqtSignal, Qt
 from PyQt5.QtGui import QCursor, QDoubleValidator, QColor
 
@@ -70,8 +72,11 @@ def wait_cursor():
 def _to_ordinalf(d):
     if d is None:
         return None
-    seconds = (d - datetime(d.year, d.month, d.day, tzinfo=d.tzinfo)).\
-               total_seconds()
+    if isinstance(d, datetime):
+        seconds = (d - datetime(d.year, d.month, d.day, tzinfo=d.tzinfo)).\
+            total_seconds()
+    else:
+        seconds = 0
     return d.toordinal() + (seconds / 24 / 60 / 60)
 _to_ordinalf_np_vectorized = np.vectorize(_to_ordinalf)
 class NoneDateConverter(type(matplotlib.units.registry[datetime])):
@@ -700,6 +705,8 @@ class BeamWidget(QWidget):
         return self.source.currentText()
 
     def get_setup_index(self):
+        if len(self.wave_index) == 0:
+            return None
         return self.wave_index[self.wavelength.currentIndex()][1]
 
     def get_oversampling(self):
@@ -727,7 +734,8 @@ class BeamWidget(QWidget):
         
         used_setups = set(scan.setnum for scan in scans)
         self.wave_index = sorted((300 / s.schsf.sffreq[0, i-1], i)
-                                 for i in used_setups)
+                                 for i in used_setups
+                                 if s.schsf.sffreq[0, i-1] > 0)
         for row, (label, attribute, options) in enumerate((
                 ("Source", "source", [s.aliases[0] for s in sources]),
                 ("Wavelength (cm)", "wavelength", 
@@ -855,7 +863,7 @@ class MainWidget(QWidget):
             rows = math.ceil(items / columns)
             with shut_up_mpl():
                 figure, axes = plt.subplots(rows, columns, squeeze=False)
-            figure.canvas.set_window_title("UV Plot")
+            figure.canvas.manager.set_window_title("UV Plot")
             axes = axes.reshape((rows * columns,))
 
             unit, multiplier = self.uv.get_unit_multiplier()
@@ -947,7 +955,7 @@ class MainWidget(QWidget):
             axis_type = [self.xy.get_x_axis(), 
                          self.xy.get_y_axis()]
 
-            figure.canvas.set_window_title("{}-{} Plot".format(
+            figure.canvas.manager.set_window_title("{}-{} Plot".format(
                 *axis_type[::-1]))
 
             axis_function = []
@@ -1073,7 +1081,7 @@ class MainWidget(QWidget):
                                             sharex=True, sharey=True)
             axes = axes.reshape((len(plot_sources),))
 
-            figure.canvas.set_window_title("Uptime Plot")
+            figure.canvas.manager.set_window_title("Uptime Plot")
 
             axis_function = []
             axis_type = self.uptime.get_x_axis()
@@ -1183,7 +1191,7 @@ class MainWidget(QWidget):
         with wait_cursor():
             with shut_up_mpl():
                 figure, axis = plt.subplots()
-            figure.canvas.set_window_title("RA-Dec Plot")
+            figure.canvas.manager.set_window_title("RA-Dec Plot")
             label_points = {}
             label_annotations = {}
             # catalogs
@@ -1270,14 +1278,19 @@ class MainWidget(QWidget):
 
     def plot_beam(self):
         with wait_cursor():
+            setup_number = self.beam.get_setup_index()
+            if setup_number is None:
+                QMessageBox.warning(self, "Cannot plot beam.",
+                                    "Incomplete frequency setup, "
+                                    "unable to create beam plot.")
+                return
             with shut_up_mpl():
                 figure, axis = plt.subplots()
-            setup_number = self.beam.get_setup_index()
             wavelength = 300 / s.schsf.sffreq[0, setup_number-1]
             wave_text = "{} cm".format(
                 "{:.1f}".format(wavelength * 100).rstrip("0").rstrip("."))
             source = self.beam.get_source()
-            figure.canvas.set_window_title("Beam Plot ({}, {})".format(
+            figure.canvas.manager.set_window_title("Beam Plot ({}, {})".format(
                 source, wave_text))
 
             aliases = set(next(s.aliases for s in self.sources 
